module.exports = {
	"0.20.0": "39.0.2171.65",
	"0.20.1": "39.0.2171.65",
	"0.20.2": "39.0.2171.65",
	"0.20.3": "39.0.2171.65",
	"0.20.4": "39.0.2171.65",
	"0.20.5": "39.0.2171.65",
	"0.20.6": "39.0.2171.65",
	"0.20.7": "39.0.2171.65",
	"0.20.8": "39.0.2171.65",
	"0.21.0": "40.0.2214.91",
	"0.21.1": "40.0.2214.91",
	"0.21.2": "40.0.2214.91",
	"0.21.3": "41.0.2272.76",
	"0.22.1": "41.0.2272.76",
	"0.22.2": "41.0.2272.76",
	"0.22.3": "41.0.2272.76",
	"0.23.0": "41.0.2272.76",
	"0.24.0": "41.0.2272.76",
	"0.25.0": "42.0.2311.107",
	"0.25.1": "42.0.2311.107",
	"0.25.2": "42.0.2311.107",
	"0.25.3": "42.0.2311.107",
	"0.26.0": "42.0.2311.107",
	"0.26.1": "42.0.2311.107",
	"0.27.0": "42.0.2311.107",
	"0.27.1": "42.0.2311.107",
	"0.27.2": "43.0.2357.65",
	"0.27.3": "43.0.2357.65",
	"0.28.0": "43.0.2357.65",
	"0.28.1": "43.0.2357.65",
	"0.28.2": "43.0.2357.65",
	"0.28.3": "43.0.2357.65",
	"0.29.1": "43.0.2357.65",
	"0.29.2": "43.0.2357.65",
	"0.30.4": "44.0.2403.125",
	"0.31.0": "44.0.2403.125",
	"0.31.2": "45.0.2454.85",
	"0.32.2": "45.0.2454.85",
	"0.32.3": "45.0.2454.85",
	"0.33.0": "45.0.2454.85",
	"0.33.1": "45.0.2454.85",
	"0.33.2": "45.0.2454.85",
	"0.33.3": "45.0.2454.85",
	"0.33.4": "45.0.2454.85",
	"0.33.6": "45.0.2454.85",
	"0.33.7": "45.0.2454.85",
	"0.33.8": "45.0.2454.85",
	"0.33.9": "45.0.2454.85",
	"0.34.0": "45.0.2454.85",
	"0.34.1": "45.0.2454.85",
	"0.34.2": "45.0.2454.85",
	"0.34.3": "45.0.2454.85",
	"0.34.4": "45.0.2454.85",
	"0.35.1": "45.0.2454.85",
	"0.35.2": "45.0.2454.85",
	"0.35.3": "45.0.2454.85",
	"0.35.4": "45.0.2454.85",
	"0.35.5": "45.0.2454.85",
	"0.36.0": "47.0.2526.73",
	"0.36.2": "47.0.2526.73",
	"0.36.3": "47.0.2526.73",
	"0.36.4": "47.0.2526.73",
	"0.36.5": "47.0.2526.110",
	"0.36.6": "47.0.2526.110",
	"0.36.7": "47.0.2526.110",
	"0.36.8": "47.0.2526.110",
	"0.36.9": "47.0.2526.110",
	"0.36.10": "47.0.2526.110",
	"0.36.11": "47.0.2526.110",
	"0.36.12": "47.0.2526.110",
	"0.37.0": "49.0.2623.75",
	"0.37.1": "49.0.2623.75",
	"0.37.3": "49.0.2623.75",
	"0.37.4": "49.0.2623.75",
	"0.37.5": "49.0.2623.75",
	"0.37.6": "49.0.2623.75",
	"0.37.7": "49.0.2623.75",
	"0.37.8": "49.0.2623.75",
	"1.0.0": "49.0.2623.75",
	"1.0.1": "49.0.2623.75",
	"1.0.2": "49.0.2623.75",
	"1.1.0": "50.0.2661.102",
	"1.1.1": "50.0.2661.102",
	"1.1.2": "50.0.2661.102",
	"1.1.3": "50.0.2661.102",
	"1.2.0": "51.0.2704.63",
	"1.2.1": "51.0.2704.63",
	"1.2.2": "51.0.2704.84",
	"1.2.3": "51.0.2704.84",
	"1.2.4": "51.0.2704.103",
	"1.2.5": "51.0.2704.103",
	"1.2.6": "51.0.2704.106",
	"1.2.7": "51.0.2704.106",
	"1.2.8": "51.0.2704.106",
	"1.3.0": "52.0.2743.82",
	"1.3.1": "52.0.2743.82",
	"1.3.2": "52.0.2743.82",
	"1.3.3": "52.0.2743.82",
	"1.3.4": "52.0.2743.82",
	"1.3.5": "52.0.2743.82",
	"1.3.6": "52.0.2743.82",
	"1.3.7": "52.0.2743.82",
	"1.3.9": "52.0.2743.82",
	"1.3.10": "52.0.2743.82",
	"1.3.13": "52.0.2743.82",
	"1.3.14": "52.0.2743.82",
	"1.3.15": "52.0.2743.82",
	"1.4.0": "53.0.2785.113",
	"1.4.1": "53.0.2785.113",
	"1.4.2": "53.0.2785.113",
	"1.4.3": "53.0.2785.113",
	"1.4.4": "53.0.2785.113",
	"1.4.5": "53.0.2785.113",
	"1.4.6": "53.0.2785.143",
	"1.4.7": "53.0.2785.143",
	"1.4.8": "53.0.2785.143",
	"1.4.10": "53.0.2785.143",
	"1.4.11": "53.0.2785.143",
	"1.4.12": "54.0.2840.51",
	"1.4.13": "53.0.2785.143",
	"1.4.14": "53.0.2785.143",
	"1.4.15": "53.0.2785.143",
	"1.4.16": "53.0.2785.143",
	"1.5.0": "54.0.2840.101",
	"1.5.1": "54.0.2840.101",
	"1.6.0": "56.0.2924.87",
	"1.6.1": "56.0.2924.87",
	"1.6.2": "56.0.2924.87",
	"1.6.3": "56.0.2924.87",
	"1.6.4": "56.0.2924.87",
	"1.6.5": "56.0.2924.87",
	"1.6.6": "56.0.2924.87",
	"1.6.7": "56.0.2924.87",
	"1.6.8": "56.0.2924.87",
	"1.6.9": "56.0.2924.87",
	"1.6.10": "56.0.2924.87",
	"1.6.11": "56.0.2924.87",
	"1.6.12": "56.0.2924.87",
	"1.6.13": "56.0.2924.87",
	"1.6.14": "56.0.2924.87",
	"1.6.15": "56.0.2924.87",
	"1.6.16": "56.0.2924.87",
	"1.6.17": "56.0.2924.87",
	"1.6.18": "56.0.2924.87",
	"1.7.0": "58.0.3029.110",
	"1.7.1": "58.0.3029.110",
	"1.7.2": "58.0.3029.110",
	"1.7.3": "58.0.3029.110",
	"1.7.4": "58.0.3029.110",
	"1.7.5": "58.0.3029.110",
	"1.7.6": "58.0.3029.110",
	"1.7.7": "58.0.3029.110",
	"1.7.8": "58.0.3029.110",
	"1.7.9": "58.0.3029.110",
	"1.7.10": "58.0.3029.110",
	"1.7.11": "58.0.3029.110",
	"1.7.12": "58.0.3029.110",
	"1.7.13": "58.0.3029.110",
	"1.7.14": "58.0.3029.110",
	"1.7.15": "58.0.3029.110",
	"1.7.16": "58.0.3029.110",
	"1.8.0": "59.0.3071.115",
	"1.8.1": "59.0.3071.115",
	"1.8.2-beta.1": "59.0.3071.115",
	"1.8.2-beta.2": "59.0.3071.115",
	"1.8.2-beta.3": "59.0.3071.115",
	"1.8.2-beta.4": "59.0.3071.115",
	"1.8.2-beta.5": "59.0.3071.115",
	"1.8.2": "59.0.3071.115",
	"1.8.3": "59.0.3071.115",
	"1.8.4": "59.0.3071.115",
	"1.8.5": "59.0.3071.115",
	"1.8.6": "59.0.3071.115",
	"1.8.7": "59.0.3071.115",
	"1.8.8": "59.0.3071.115",
	"2.0.0-beta.1": "61.0.3163.100",
	"2.0.0-beta.2": "61.0.3163.100",
	"2.0.0-beta.3": "61.0.3163.100",
	"2.0.0-beta.4": "61.0.3163.100",
	"2.0.0-beta.5": "61.0.3163.100",
	"2.0.0-beta.6": "61.0.3163.100",
	"2.0.0-beta.7": "61.0.3163.100",
	"2.0.0-beta.8": "61.0.3163.100",
	"2.0.0": "61.0.3163.100",
	"2.0.1": "61.0.3163.100",
	"2.0.2": "61.0.3163.100",
	"2.0.3": "61.0.3163.100",
	"2.0.4": "61.0.3163.100",
	"2.0.5": "61.0.3163.100",
	"2.0.6": "61.0.3163.100",
	"2.0.7": "61.0.3163.100",
	"2.0.8": "61.0.3163.100",
	"2.0.9": "61.0.3163.100",
	"2.0.10": "61.0.3163.100",
	"2.0.11": "61.0.3163.100",
	"2.0.12": "61.0.3163.100",
	"2.0.13": "61.0.3163.100",
	"2.0.14": "61.0.3163.100",
	"2.0.15": "61.0.3163.100",
	"2.0.16": "61.0.3163.100",
	"2.0.17": "61.0.3163.100",
	"2.0.18": "61.0.3163.100",
	"2.1.0-unsupported.20180809": "61.0.3163.100",
	"3.0.0-beta.1": "66.0.3359.181",
	"3.0.0-beta.2": "66.0.3359.181",
	"3.0.0-beta.3": "66.0.3359.181",
	"3.0.0-beta.4": "66.0.3359.181",
	"3.0.0-beta.5": "66.0.3359.181",
	"3.0.0-beta.6": "66.0.3359.181",
	"3.0.0-beta.7": "66.0.3359.181",
	"3.0.0-beta.8": "66.0.3359.181",
	"3.0.0-beta.9": "66.0.3359.181",
	"3.0.0-beta.10": "66.0.3359.181",
	"3.0.0-beta.11": "66.0.3359.181",
	"3.0.0-beta.12": "66.0.3359.181",
	"3.0.0-beta.13": "66.0.3359.181",
	"3.0.0": "66.0.3359.181",
	"3.0.1": "66.0.3359.181",
	"3.0.2": "66.0.3359.181",
	"3.0.3": "66.0.3359.181",
	"3.0.4": "66.0.3359.181",
	"3.0.5": "66.0.3359.181",
	"3.0.6": "66.0.3359.181",
	"3.0.7": "66.0.3359.181",
	"3.0.8": "66.0.3359.181",
	"3.0.9": "66.0.3359.181",
	"3.0.10": "66.0.3359.181",
	"3.0.11": "66.0.3359.181",
	"3.0.12": "66.0.3359.181",
	"3.0.13": "66.0.3359.181",
	"3.0.14": "66.0.3359.181",
	"3.0.15": "66.0.3359.181",
	"3.0.16": "66.0.3359.181",
	"3.1.0-beta.1": "66.0.3359.181",
	"3.1.0-beta.2": "66.0.3359.181",
	"3.1.0-beta.3": "66.0.3359.181",
	"3.1.0-beta.4": "66.0.3359.181",
	"3.1.0-beta.5": "66.0.3359.181",
	"3.1.0": "66.0.3359.181",
	"3.1.1": "66.0.3359.181",
	"3.1.2": "66.0.3359.181",
	"3.1.3": "66.0.3359.181",
	"3.1.4": "66.0.3359.181",
	"3.1.5": "66.0.3359.181",
	"3.1.6": "66.0.3359.181",
	"3.1.7": "66.0.3359.181",
	"3.1.8": "66.0.3359.181",
	"3.1.9": "66.0.3359.181",
	"3.1.10": "66.0.3359.181",
	"3.1.11": "66.0.3359.181",
	"3.1.12": "66.0.3359.181",
	"3.1.13": "66.0.3359.181",
	"4.0.0-beta.1": "69.0.3497.106",
	"4.0.0-beta.2": "69.0.3497.106",
	"4.0.0-beta.3": "69.0.3497.106",
	"4.0.0-beta.4": "69.0.3497.106",
	"4.0.0-beta.5": "69.0.3497.106",
	"4.0.0-beta.6": "69.0.3497.106",
	"4.0.0-beta.7": "69.0.3497.106",
	"4.0.0-beta.8": "69.0.3497.106",
	"4.0.0-beta.9": "69.0.3497.106",
	"4.0.0-beta.10": "69.0.3497.106",
	"4.0.0-beta.11": "69.0.3497.106",
	"4.0.0": "69.0.3497.106",
	"4.0.1": "69.0.3497.106",
	"4.0.2": "69.0.3497.106",
	"4.0.3": "69.0.3497.106",
	"4.0.4": "69.0.3497.106",
	"4.0.5": "69.0.3497.106",
	"4.0.6": "69.0.3497.106",
	"4.0.7": "69.0.3497.128",
	"4.0.8": "69.0.3497.128",
	"4.1.0": "69.0.3497.128",
	"4.1.1": "69.0.3497.128",
	"4.1.2": "69.0.3497.128",
	"4.1.3": "69.0.3497.128",
	"4.1.4": "69.0.3497.128",
	"4.1.5": "69.0.3497.128",
	"4.2.0": "69.0.3497.128",
	"4.2.1": "69.0.3497.128",
	"4.2.2": "69.0.3497.128",
	"4.2.3": "69.0.3497.128",
	"4.2.4": "69.0.3497.128",
	"4.2.5": "69.0.3497.128",
	"4.2.6": "69.0.3497.128",
	"4.2.7": "69.0.3497.128",
	"4.2.8": "69.0.3497.128",
	"4.2.9": "69.0.3497.128",
	"4.2.10": "69.0.3497.128",
	"4.2.11": "69.0.3497.128",
	"4.2.12": "69.0.3497.128",
	"5.0.0-beta.1": "72.0.3626.52",
	"5.0.0-beta.2": "72.0.3626.52",
	"5.0.0-beta.3": "73.0.3683.27",
	"5.0.0-beta.4": "73.0.3683.54",
	"5.0.0-beta.5": "73.0.3683.61",
	"5.0.0-beta.6": "73.0.3683.84",
	"5.0.0-beta.7": "73.0.3683.94",
	"5.0.0-beta.8": "73.0.3683.104",
	"5.0.0-beta.9": "73.0.3683.117",
	"5.0.0": "73.0.3683.119",
	"5.0.1": "73.0.3683.121",
	"5.0.2": "73.0.3683.121",
	"5.0.3": "73.0.3683.121",
	"5.0.4": "73.0.3683.121",
	"5.0.5": "73.0.3683.121",
	"5.0.6": "73.0.3683.121",
	"5.0.7": "73.0.3683.121",
	"5.0.8": "73.0.3683.121",
	"5.0.9": "73.0.3683.121",
	"5.0.10": "73.0.3683.121",
	"5.0.11": "73.0.3683.121",
	"5.0.12": "73.0.3683.121",
	"5.0.13": "73.0.3683.121",
	"6.0.0-beta.1": "76.0.3774.1",
	"6.0.0-beta.2": "76.0.3783.1",
	"6.0.0-beta.3": "76.0.3783.1",
	"6.0.0-beta.4": "76.0.3783.1",
	"6.0.0-beta.5": "76.0.3805.4",
	"6.0.0-beta.6": "76.0.3809.3",
	"6.0.0-beta.7": "76.0.3809.22",
	"6.0.0-beta.8": "76.0.3809.26",
	"6.0.0-beta.9": "76.0.3809.26",
	"6.0.0-beta.10": "76.0.3809.37",
	"6.0.0-beta.11": "76.0.3809.42",
	"6.0.0-beta.12": "76.0.3809.54",
	"6.0.0-beta.13": "76.0.3809.60",
	"6.0.0-beta.14": "76.0.3809.68",
	"6.0.0-beta.15": "76.0.3809.74",
	"6.0.0": "76.0.3809.88",
	"6.0.1": "76.0.3809.102",
	"6.0.2": "76.0.3809.110",
	"6.0.3": "76.0.3809.126",
	"6.0.4": "76.0.3809.131",
	"6.0.5": "76.0.3809.136",
	"6.0.6": "76.0.3809.138",
	"6.0.7": "76.0.3809.139",
	"6.0.8": "76.0.3809.146",
	"6.0.9": "76.0.3809.146",
	"6.0.10": "76.0.3809.146",
	"6.0.11": "76.0.3809.146",
	"6.0.12": "76.0.3809.146",
	"6.1.0": "76.0.3809.146",
	"6.1.1": "76.0.3809.146",
	"6.1.2": "76.0.3809.146",
	"6.1.3": "76.0.3809.146",
	"6.1.4": "76.0.3809.146",
	"6.1.5": "76.0.3809.146",
	"6.1.6": "76.0.3809.146",
	"6.1.7": "76.0.3809.146",
	"6.1.8": "76.0.3809.146",
	"6.1.9": "76.0.3809.146",
	"6.1.10": "76.0.3809.146",
	"6.1.11": "76.0.3809.146",
	"6.1.12": "76.0.3809.146",
	"7.0.0-beta.1": "78.0.3866.0",
	"7.0.0-beta.2": "78.0.3866.0",
	"7.0.0-beta.3": "78.0.3866.0",
	"7.0.0-beta.4": "78.0.3896.6",
	"7.0.0-beta.5": "78.0.3905.1",
	"7.0.0-beta.6": "78.0.3905.1",
	"7.0.0-beta.7": "78.0.3905.1",
	"7.0.0": "78.0.3905.1",
	"7.0.1": "78.0.3904.92",
	"7.1.0": "78.0.3904.94",
	"7.1.1": "78.0.3904.99",
	"7.1.2": "78.0.3904.113",
	"7.1.3": "78.0.3904.126",
	"7.1.4": "78.0.3904.130",
	"7.1.5": "78.0.3904.130",
	"7.1.6": "78.0.3904.130",
	"7.1.7": "78.0.3904.130",
	"7.1.8": "78.0.3904.130",
	"7.1.9": "78.0.3904.130",
	"7.1.10": "78.0.3904.130",
	"7.1.11": "78.0.3904.130",
	"7.1.12": "78.0.3904.130",
	"7.1.13": "78.0.3904.130",
	"7.1.14": "78.0.3904.130",
	"7.2.0": "78.0.3904.130",
	"7.2.1": "78.0.3904.130",
	"7.2.2": "78.0.3904.130",
	"7.2.3": "78.0.3904.130",
	"7.2.4": "78.0.3904.130",
	"7.3.0": "78.0.3904.130",
	"7.3.1": "78.0.3904.130",
	"7.3.2": "78.0.3904.130",
	"7.3.3": "78.0.3904.130",
	"8.0.0-beta.1": "79.0.3931.0",
	"8.0.0-beta.2": "79.0.3931.0",
	"8.0.0-beta.3": "80.0.3955.0",
	"8.0.0-beta.4": "80.0.3955.0",
	"8.0.0-beta.5": "80.0.3987.14",
	"8.0.0-beta.6": "80.0.3987.51",
	"8.0.0-beta.7": "80.0.3987.59",
	"8.0.0-beta.8": "80.0.3987.75",
	"8.0.0-beta.9": "80.0.3987.75",
	"8.0.0": "80.0.3987.86",
	"8.0.1": "80.0.3987.86",
	"8.0.2": "80.0.3987.86",
	"8.0.3": "80.0.3987.134",
	"8.1.0": "80.0.3987.137",
	"8.1.1": "80.0.3987.141",
	"8.2.0": "80.0.3987.158",
	"8.2.1": "80.0.3987.163",
	"8.2.2": "80.0.3987.163",
	"8.2.3": "80.0.3987.163",
	"8.2.4": "80.0.3987.165",
	"8.2.5": "80.0.3987.165",
	"8.3.0": "80.0.3987.165",
	"8.3.1": "80.0.3987.165",
	"8.3.2": "80.0.3987.165",
	"8.3.3": "80.0.3987.165",
	"8.3.4": "80.0.3987.165",
	"8.4.0": "80.0.3987.165",
	"8.4.1": "80.0.3987.165",
	"8.5.0": "80.0.3987.165",
	"8.5.1": "80.0.3987.165",
	"8.5.2": "80.0.3987.165",
	"8.5.3": "80.0.3987.163",
	"8.5.4": "80.0.3987.163",
	"8.5.5": "80.0.3987.163",
	"9.0.0-beta.1": "82.0.4048.0",
	"9.0.0-beta.2": "82.0.4048.0",
	"9.0.0-beta.3": "82.0.4048.0",
	"9.0.0-beta.4": "82.0.4048.0",
	"9.0.0-beta.5": "82.0.4048.0",
	"9.0.0-beta.6": "82.0.4058.2",
	"9.0.0-beta.7": "82.0.4058.2",
	"9.0.0-beta.9": "82.0.4058.2",
	"9.0.0-beta.10": "82.0.4085.10",
	"9.0.0-beta.11": "82.0.4085.14",
	"9.0.0-beta.12": "82.0.4085.14",
	"9.0.0-beta.13": "82.0.4085.14",
	"9.0.0-beta.14": "82.0.4085.27",
	"9.0.0-beta.15": "83.0.4102.3",
	"9.0.0-beta.16": "83.0.4102.3",
	"9.0.0-beta.17": "83.0.4103.14",
	"9.0.0-beta.18": "83.0.4103.16",
	"9.0.0-beta.19": "83.0.4103.24",
	"9.0.0-beta.20": "83.0.4103.26",
	"9.0.0-beta.21": "83.0.4103.26",
	"9.0.0-beta.22": "83.0.4103.34",
	"9.0.0-beta.23": "83.0.4103.44",
	"9.0.0-beta.24": "83.0.4103.45",
	"9.0.0": "83.0.4103.64",
	"9.0.1": "83.0.4103.94",
	"9.0.2": "83.0.4103.94",
	"9.0.3": "83.0.4103.100",
	"9.0.4": "83.0.4103.104",
	"9.0.5": "83.0.4103.119",
	"9.1.0": "83.0.4103.122",
	"9.1.1": "83.0.4103.122",
	"9.1.2": "83.0.4103.122",
	"9.2.0": "83.0.4103.122",
	"9.2.1": "83.0.4103.122",
	"9.3.0": "83.0.4103.122",
	"9.3.1": "83.0.4103.122",
	"9.3.2": "83.0.4103.122",
	"9.3.3": "83.0.4103.122",
	"9.3.4": "83.0.4103.122",
	"9.3.5": "83.0.4103.122",
	"9.4.0": "83.0.4103.122",
	"9.4.1": "83.0.4103.122",
	"9.4.2": "83.0.4103.122",
	"9.4.3": "83.0.4103.122",
	"9.4.4": "83.0.4103.122",
	"10.0.0-beta.1": "84.0.4129.0",
	"10.0.0-beta.2": "84.0.4129.0",
	"10.0.0-beta.3": "85.0.4161.2",
	"10.0.0-beta.4": "85.0.4161.2",
	"10.0.0-beta.8": "85.0.4181.1",
	"10.0.0-beta.9": "85.0.4181.1",
	"10.0.0-beta.10": "85.0.4183.19",
	"10.0.0-beta.11": "85.0.4183.20",
	"10.0.0-beta.12": "85.0.4183.26",
	"10.0.0-beta.13": "85.0.4183.39",
	"10.0.0-beta.14": "85.0.4183.39",
	"10.0.0-beta.15": "85.0.4183.39",
	"10.0.0-beta.17": "85.0.4183.39",
	"10.0.0-beta.19": "85.0.4183.39",
	"10.0.0-beta.20": "85.0.4183.39",
	"10.0.0-beta.21": "85.0.4183.39",
	"10.0.0-beta.23": "85.0.4183.70",
	"10.0.0-beta.24": "85.0.4183.78",
	"10.0.0-beta.25": "85.0.4183.80",
	"10.0.0": "85.0.4183.84",
	"10.0.1": "85.0.4183.86",
	"10.1.0": "85.0.4183.87",
	"10.1.1": "85.0.4183.93",
	"10.1.2": "85.0.4183.98",
	"10.1.3": "85.0.4183.121",
	"10.1.4": "85.0.4183.121",
	"10.1.5": "85.0.4183.121",
	"10.1.6": "85.0.4183.121",
	"10.1.7": "85.0.4183.121",
	"10.2.0": "85.0.4183.121",
	"10.3.0": "85.0.4183.121",
	"10.3.1": "85.0.4183.121",
	"10.3.2": "85.0.4183.121",
	"10.4.0": "85.0.4183.121",
	"10.4.1": "85.0.4183.121",
	"10.4.2": "85.0.4183.121",
	"10.4.3": "85.0.4183.121",
	"10.4.4": "85.0.4183.121",
	"10.4.5": "85.0.4183.121",
	"10.4.6": "85.0.4183.121",
	"10.4.7": "85.0.4183.121",
	"11.0.0-beta.1": "86.0.4234.0",
	"11.0.0-beta.3": "86.0.4234.0",
	"11.0.0-beta.4": "86.0.4234.0",
	"11.0.0-beta.5": "86.0.4234.0",
	"11.0.0-beta.6": "86.0.4234.0",
	"11.0.0-beta.7": "86.0.4234.0",
	"11.0.0-beta.8": "87.0.4251.1",
	"11.0.0-beta.9": "87.0.4251.1",
	"11.0.0-beta.11": "87.0.4251.1",
	"11.0.0-beta.12": "87.0.4280.11",
	"11.0.0-beta.13": "87.0.4280.11",
	"11.0.0-beta.16": "87.0.4280.27",
	"11.0.0-beta.17": "87.0.4280.27",
	"11.0.0-beta.18": "87.0.4280.27",
	"11.0.0-beta.19": "87.0.4280.27",
	"11.0.0-beta.20": "87.0.4280.40",
	"11.0.0-beta.22": "87.0.4280.47",
	"11.0.0-beta.23": "87.0.4280.47",
	"11.0.0": "87.0.4280.60",
	"11.0.1": "87.0.4280.60",
	"11.0.2": "87.0.4280.67",
	"11.0.3": "87.0.4280.67",
	"11.0.4": "87.0.4280.67",
	"11.0.5": "87.0.4280.88",
	"11.1.0": "87.0.4280.88",
	"11.1.1": "87.0.4280.88",
	"11.2.0": "87.0.4280.141",
	"11.2.1": "87.0.4280.141",
	"11.2.2": "87.0.4280.141",
	"11.2.3": "87.0.4280.141",
	"11.3.0": "87.0.4280.141",
	"11.4.0": "87.0.4280.141",
	"11.4.1": "87.0.4280.141",
	"11.4.2": "87.0.4280.141",
	"11.4.3": "87.0.4280.141",
	"11.4.4": "87.0.4280.141",
	"11.4.5": "87.0.4280.141",
	"11.4.6": "87.0.4280.141",
	"11.4.7": "87.0.4280.141",
	"11.4.8": "87.0.4280.141",
	"11.4.9": "87.0.4280.141",
	"11.4.10": "87.0.4280.141",
	"11.4.11": "87.0.4280.141",
	"11.4.12": "87.0.4280.141",
	"11.5.0": "87.0.4280.141",
	"12.0.0-beta.1": "89.0.4328.0",
	"12.0.0-beta.3": "89.0.4328.0",
	"12.0.0-beta.4": "89.0.4328.0",
	"12.0.0-beta.5": "89.0.4328.0",
	"12.0.0-beta.6": "89.0.4328.0",
	"12.0.0-beta.7": "89.0.4328.0",
	"12.0.0-beta.8": "89.0.4328.0",
	"12.0.0-beta.9": "89.0.4328.0",
	"12.0.0-beta.10": "89.0.4328.0",
	"12.0.0-beta.11": "89.0.4328.0",
	"12.0.0-beta.12": "89.0.4328.0",
	"12.0.0-beta.14": "89.0.4328.0",
	"12.0.0-beta.16": "89.0.4348.1",
	"12.0.0-beta.18": "89.0.4348.1",
	"12.0.0-beta.19": "89.0.4348.1",
	"12.0.0-beta.20": "89.0.4348.1",
	"12.0.0-beta.21": "89.0.4388.2",
	"12.0.0-beta.22": "89.0.4388.2",
	"12.0.0-beta.23": "89.0.4388.2",
	"12.0.0-beta.24": "89.0.4388.2",
	"12.0.0-beta.25": "89.0.4388.2",
	"12.0.0-beta.26": "89.0.4388.2",
	"12.0.0-beta.27": "89.0.4389.23",
	"12.0.0-beta.28": "89.0.4389.23",
	"12.0.0-beta.29": "89.0.4389.23",
	"12.0.0-beta.30": "89.0.4389.58",
	"12.0.0-beta.31": "89.0.4389.58",
	"12.0.0": "89.0.4389.69",
	"12.0.1": "89.0.4389.82",
	"12.0.2": "89.0.4389.90",
	"12.0.3": "89.0.4389.114",
	"12.0.4": "89.0.4389.114",
	"12.0.5": "89.0.4389.128",
	"12.0.6": "89.0.4389.128",
	"12.0.7": "89.0.4389.128",
	"12.0.8": "89.0.4389.128",
	"12.0.9": "89.0.4389.128",
	"12.0.10": "89.0.4389.128",
	"12.0.11": "89.0.4389.128",
	"12.0.12": "89.0.4389.128",
	"12.0.13": "89.0.4389.128",
	"12.0.14": "89.0.4389.128",
	"12.0.15": "89.0.4389.128",
	"12.0.16": "89.0.4389.128",
	"12.0.17": "89.0.4389.128",
	"12.0.18": "89.0.4389.128",
	"12.1.0": "89.0.4389.128",
	"12.1.1": "89.0.4389.128",
	"12.1.2": "89.0.4389.128",
	"12.2.0": "89.0.4389.128",
	"12.2.1": "89.0.4389.128",
	"12.2.2": "89.0.4389.128",
	"12.2.3": "89.0.4389.128",
	"13.0.0-beta.2": "90.0.4402.0",
	"13.0.0-beta.3": "90.0.4402.0",
	"13.0.0-beta.4": "90.0.4415.0",
	"13.0.0-beta.5": "90.0.4415.0",
	"13.0.0-beta.6": "90.0.4415.0",
	"13.0.0-beta.7": "90.0.4415.0",
	"13.0.0-beta.8": "90.0.4415.0",
	"13.0.0-beta.9": "90.0.4415.0",
	"13.0.0-beta.10": "90.0.4415.0",
	"13.0.0-beta.11": "90.0.4415.0",
	"13.0.0-beta.12": "90.0.4415.0",
	"13.0.0-beta.13": "90.0.4415.0",
	"13.0.0-beta.14": "91.0.4448.0",
	"13.0.0-beta.16": "91.0.4448.0",
	"13.0.0-beta.17": "91.0.4448.0",
	"13.0.0-beta.18": "91.0.4448.0",
	"13.0.0-beta.20": "91.0.4448.0",
	"13.0.0-beta.21": "91.0.4472.33",
	"13.0.0-beta.22": "91.0.4472.33",
	"13.0.0-beta.23": "91.0.4472.33",
	"13.0.0-beta.24": "91.0.4472.38",
	"13.0.0-beta.25": "91.0.4472.38",
	"13.0.0-beta.26": "91.0.4472.38",
	"13.0.0-beta.27": "91.0.4472.38",
	"13.0.0-beta.28": "91.0.4472.38",
	"13.0.0": "91.0.4472.69",
	"13.0.1": "91.0.4472.69",
	"13.1.0": "91.0.4472.77",
	"13.1.1": "91.0.4472.77",
	"13.1.2": "91.0.4472.77",
	"13.1.3": "91.0.4472.106",
	"13.1.4": "91.0.4472.106",
	"13.1.5": "91.0.4472.124",
	"13.1.6": "91.0.4472.124",
	"13.1.7": "91.0.4472.124",
	"13.1.8": "91.0.4472.164",
	"13.1.9": "91.0.4472.164",
	"13.2.0": "91.0.4472.164",
	"13.2.1": "91.0.4472.164",
	"13.2.2": "91.0.4472.164",
	"13.2.3": "91.0.4472.164",
	"13.3.0": "91.0.4472.164",
	"13.4.0": "91.0.4472.164",
	"13.5.0": "91.0.4472.164",
	"13.5.1": "91.0.4472.164",
	"13.5.2": "91.0.4472.164",
	"13.6.0": "91.0.4472.164",
	"13.6.1": "91.0.4472.164",
	"13.6.2": "91.0.4472.164",
	"13.6.3": "91.0.4472.164",
	"13.6.6": "91.0.4472.164",
	"13.6.7": "91.0.4472.164",
	"13.6.8": "91.0.4472.164",
	"13.6.9": "91.0.4472.164",
	"14.0.0-beta.1": "92.0.4511.0",
	"14.0.0-beta.2": "92.0.4511.0",
	"14.0.0-beta.3": "92.0.4511.0",
	"14.0.0-beta.5": "93.0.4536.0",
	"14.0.0-beta.6": "93.0.4536.0",
	"14.0.0-beta.7": "93.0.4536.0",
	"14.0.0-beta.8": "93.0.4536.0",
	"14.0.0-beta.9": "93.0.4539.0",
	"14.0.0-beta.10": "93.0.4539.0",
	"14.0.0-beta.11": "93.0.4557.4",
	"14.0.0-beta.12": "93.0.4557.4",
	"14.0.0-beta.13": "93.0.4566.0",
	"14.0.0-beta.14": "93.0.4566.0",
	"14.0.0-beta.15": "93.0.4566.0",
	"14.0.0-beta.16": "93.0.4566.0",
	"14.0.0-beta.17": "93.0.4566.0",
	"14.0.0-beta.18": "93.0.4577.15",
	"14.0.0-beta.19": "93.0.4577.15",
	"14.0.0-beta.20": "93.0.4577.15",
	"14.0.0-beta.21": "93.0.4577.15",
	"14.0.0-beta.22": "93.0.4577.25",
	"14.0.0-beta.23": "93.0.4577.25",
	"14.0.0-beta.24": "93.0.4577.51",
	"14.0.0-beta.25": "93.0.4577.51",
	"14.0.0": "93.0.4577.58",
	"14.0.1": "93.0.4577.63",
	"14.0.2": "93.0.4577.82",
	"14.1.0": "93.0.4577.82",
	"14.1.1": "93.0.4577.82",
	"14.2.0": "93.0.4577.82",
	"14.2.1": "93.0.4577.82",
	"14.2.2": "93.0.4577.82",
	"14.2.3": "93.0.4577.82",
	"14.2.4": "93.0.4577.82",
	"14.2.5": "93.0.4577.82",
	"14.2.6": "93.0.4577.82",
	"14.2.7": "93.0.4577.82",
	"14.2.8": "93.0.4577.82",
	"14.2.9": "93.0.4577.82",
	"15.0.0-alpha.1": "93.0.4566.0",
	"15.0.0-alpha.2": "93.0.4566.0",
	"15.0.0-alpha.3": "94.0.4584.0",
	"15.0.0-alpha.4": "94.0.4584.0",
	"15.0.0-alpha.5": "94.0.4584.0",
	"15.0.0-alpha.6": "94.0.4584.0",
	"15.0.0-alpha.7": "94.0.4590.2",
	"15.0.0-alpha.8": "94.0.4590.2",
	"15.0.0-alpha.9": "94.0.4590.2",
	"15.0.0-alpha.10": "94.0.4606.12",
	"15.0.0-beta.1": "94.0.4606.20",
	"15.0.0-beta.2": "94.0.4606.20",
	"15.0.0-beta.3": "94.0.4606.31",
	"15.0.0-beta.4": "94.0.4606.31",
	"15.0.0-beta.5": "94.0.4606.31",
	"15.0.0-beta.6": "94.0.4606.31",
	"15.0.0-beta.7": "94.0.4606.31",
	"15.0.0": "94.0.4606.51",
	"15.1.0": "94.0.4606.61",
	"15.1.1": "94.0.4606.61",
	"15.1.2": "94.0.4606.71",
	"15.2.0": "94.0.4606.81",
	"15.3.0": "94.0.4606.81",
	"15.3.1": "94.0.4606.81",
	"15.3.2": "94.0.4606.81",
	"15.3.3": "94.0.4606.81",
	"15.3.4": "94.0.4606.81",
	"15.3.5": "94.0.4606.81",
	"15.3.6": "94.0.4606.81",
	"15.3.7": "94.0.4606.81",
	"15.4.0": "94.0.4606.81",
	"15.4.1": "94.0.4606.81",
	"15.4.2": "94.0.4606.81",
	"15.5.0": "94.0.4606.81",
	"15.5.1": "94.0.4606.81",
	"15.5.2": "94.0.4606.81",
	"15.5.3": "94.0.4606.81",
	"15.5.4": "94.0.4606.81",
	"15.5.5": "94.0.4606.81",
	"15.5.6": "94.0.4606.81",
	"15.5.7": "94.0.4606.81",
	"16.0.0-alpha.1": "95.0.4629.0",
	"16.0.0-alpha.2": "95.0.4629.0",
	"16.0.0-alpha.3": "95.0.4629.0",
	"16.0.0-alpha.4": "95.0.4629.0",
	"16.0.0-alpha.5": "95.0.4629.0",
	"16.0.0-alpha.6": "95.0.4629.0",
	"16.0.0-alpha.7": "95.0.4629.0",
	"16.0.0-alpha.8": "96.0.4647.0",
	"16.0.0-alpha.9": "96.0.4647.0",
	"16.0.0-beta.1": "96.0.4647.0",
	"16.0.0-beta.2": "96.0.4647.0",
	"16.0.0-beta.3": "96.0.4647.0",
	"16.0.0-beta.4": "96.0.4664.18",
	"16.0.0-beta.5": "96.0.4664.18",
	"16.0.0-beta.6": "96.0.4664.27",
	"16.0.0-beta.7": "96.0.4664.27",
	"16.0.0-beta.8": "96.0.4664.35",
	"16.0.0-beta.9": "96.0.4664.35",
	"16.0.0": "96.0.4664.45",
	"16.0.1": "96.0.4664.45",
	"16.0.2": "96.0.4664.55",
	"16.0.3": "96.0.4664.55",
	"16.0.4": "96.0.4664.55",
	"16.0.5": "96.0.4664.55",
	"16.0.6": "96.0.4664.110",
	"16.0.7": "96.0.4664.110",
	"16.0.8": "96.0.4664.110",
	"16.0.9": "96.0.4664.174",
	"16.0.10": "96.0.4664.174",
	"16.1.0": "96.0.4664.174",
	"16.1.1": "96.0.4664.174",
	"16.2.0": "96.0.4664.174",
	"16.2.1": "96.0.4664.174",
	"16.2.2": "96.0.4664.174",
	"16.2.3": "96.0.4664.174",
	"16.2.4": "96.0.4664.174",
	"16.2.5": "96.0.4664.174",
	"16.2.6": "96.0.4664.174",
	"16.2.7": "96.0.4664.174",
	"16.2.8": "96.0.4664.174",
	"17.0.0-alpha.1": "96.0.4664.4",
	"17.0.0-alpha.2": "96.0.4664.4",
	"17.0.0-alpha.3": "96.0.4664.4",
	"17.0.0-alpha.4": "98.0.4706.0",
	"17.0.0-alpha.5": "98.0.4706.0",
	"17.0.0-alpha.6": "98.0.4706.0",
	"17.0.0-beta.1": "98.0.4706.0",
	"17.0.0-beta.2": "98.0.4706.0",
	"17.0.0-beta.3": "98.0.4758.9",
	"17.0.0-beta.4": "98.0.4758.11",
	"17.0.0-beta.5": "98.0.4758.11",
	"17.0.0-beta.6": "98.0.4758.11",
	"17.0.0-beta.7": "98.0.4758.11",
	"17.0.0-beta.8": "98.0.4758.11",
	"17.0.0-beta.9": "98.0.4758.11",
	"17.0.0": "98.0.4758.74",
	"17.0.1": "98.0.4758.82",
	"17.1.0": "98.0.4758.102",
	"17.1.1": "98.0.4758.109",
	"17.1.2": "98.0.4758.109",
	"17.2.0": "98.0.4758.109",
	"17.3.0": "98.0.4758.141",
	"17.3.1": "98.0.4758.141",
	"17.4.0": "98.0.4758.141",
	"17.4.1": "98.0.4758.141",
	"17.4.2": "98.0.4758.141",
	"17.4.3": "98.0.4758.141",
	"17.4.4": "98.0.4758.141",
	"17.4.5": "98.0.4758.141",
	"17.4.6": "98.0.4758.141",
	"17.4.7": "98.0.4758.141",
	"17.4.8": "98.0.4758.141",
	"17.4.9": "98.0.4758.141",
	"17.4.10": "98.0.4758.141",
	"17.4.11": "98.0.4758.141",
	"18.0.0-alpha.1": "99.0.4767.0",
	"18.0.0-alpha.2": "99.0.4767.0",
	"18.0.0-alpha.3": "99.0.4767.0",
	"18.0.0-alpha.4": "99.0.4767.0",
	"18.0.0-alpha.5": "99.0.4767.0",
	"18.0.0-beta.1": "100.0.4894.0",
	"18.0.0-beta.2": "100.0.4894.0",
	"18.0.0-beta.3": "100.0.4894.0",
	"18.0.0-beta.4": "100.0.4894.0",
	"18.0.0-beta.5": "100.0.4894.0",
	"18.0.0-beta.6": "100.0.4894.0",
	"18.0.0": "100.0.4896.56",
	"18.0.1": "100.0.4896.60",
	"18.0.2": "100.0.4896.60",
	"18.0.3": "100.0.4896.75",
	"18.0.4": "100.0.4896.75",
	"18.1.0": "100.0.4896.127",
	"18.2.0": "100.0.4896.143",
	"18.2.1": "100.0.4896.143",
	"18.2.2": "100.0.4896.143",
	"18.2.3": "100.0.4896.143",
	"18.2.4": "100.0.4896.160",
	"18.3.0": "100.0.4896.160",
	"18.3.1": "100.0.4896.160",
	"18.3.2": "100.0.4896.160",
	"18.3.3": "100.0.4896.160",
	"18.3.4": "100.0.4896.160",
	"18.3.5": "100.0.4896.160",
	"18.3.6": "100.0.4896.160",
	"18.3.7": "100.0.4896.160",
	"18.3.8": "100.0.4896.160",
	"18.3.9": "100.0.4896.160",
	"18.3.11": "100.0.4896.160",
	"18.3.12": "100.0.4896.160",
	"18.3.13": "100.0.4896.160",
	"18.3.14": "100.0.4896.160",
	"18.3.15": "100.0.4896.160",
	"19.0.0-alpha.1": "102.0.4962.3",
	"19.0.0-alpha.2": "102.0.4971.0",
	"19.0.0-alpha.3": "102.0.4971.0",
	"19.0.0-alpha.4": "102.0.4989.0",
	"19.0.0-alpha.5": "102.0.4989.0",
	"19.0.0-beta.1": "102.0.4999.0",
	"19.0.0-beta.2": "102.0.4999.0",
	"19.0.0-beta.3": "102.0.4999.0",
	"19.0.0-beta.4": "102.0.5005.27",
	"19.0.0-beta.5": "102.0.5005.40",
	"19.0.0-beta.6": "102.0.5005.40",
	"19.0.0-beta.7": "102.0.5005.40",
	"19.0.0-beta.8": "102.0.5005.49",
	"19.0.0": "102.0.5005.61",
	"19.0.1": "102.0.5005.61",
	"19.0.2": "102.0.5005.63",
	"19.0.3": "102.0.5005.63",
	"19.0.4": "102.0.5005.63",
	"19.0.5": "102.0.5005.115",
	"19.0.6": "102.0.5005.115",
	"19.0.7": "102.0.5005.134",
	"19.0.8": "102.0.5005.148",
	"19.0.9": "102.0.5005.167",
	"19.0.10": "102.0.5005.167",
	"19.0.11": "102.0.5005.167",
	"19.0.12": "102.0.5005.167",
	"19.0.13": "102.0.5005.167",
	"19.0.14": "102.0.5005.167",
	"19.0.15": "102.0.5005.167",
	"19.0.16": "102.0.5005.167",
	"19.0.17": "102.0.5005.167",
	"19.1.0": "102.0.5005.167",
	"19.1.1": "102.0.5005.167",
	"19.1.2": "102.0.5005.167",
	"19.1.3": "102.0.5005.167",
	"19.1.4": "102.0.5005.167",
	"19.1.5": "102.0.5005.167",
	"19.1.6": "102.0.5005.167",
	"19.1.7": "102.0.5005.167",
	"19.1.8": "102.0.5005.167",
	"19.1.9": "102.0.5005.167",
	"20.0.0-alpha.1": "103.0.5044.0",
	"20.0.0-alpha.2": "104.0.5073.0",
	"20.0.0-alpha.3": "104.0.5073.0",
	"20.0.0-alpha.4": "104.0.5073.0",
	"20.0.0-alpha.5": "104.0.5073.0",
	"20.0.0-alpha.6": "104.0.5073.0",
	"20.0.0-alpha.7": "104.0.5073.0",
	"20.0.0-beta.1": "104.0.5073.0",
	"20.0.0-beta.2": "104.0.5073.0",
	"20.0.0-beta.3": "104.0.5073.0",
	"20.0.0-beta.4": "104.0.5073.0",
	"20.0.0-beta.5": "104.0.5073.0",
	"20.0.0-beta.6": "104.0.5073.0",
	"20.0.0-beta.7": "104.0.5073.0",
	"20.0.0-beta.8": "104.0.5073.0",
	"20.0.0-beta.9": "104.0.5112.39",
	"20.0.0-beta.10": "104.0.5112.48",
	"20.0.0-beta.11": "104.0.5112.48",
	"20.0.0-beta.12": "104.0.5112.48",
	"20.0.0-beta.13": "104.0.5112.57",
	"20.0.0": "104.0.5112.65",
	"20.0.1": "104.0.5112.81",
	"20.0.2": "104.0.5112.81",
	"20.0.3": "104.0.5112.81",
	"20.1.0": "104.0.5112.102",
	"20.1.1": "104.0.5112.102",
	"20.1.2": "104.0.5112.114",
	"20.1.3": "104.0.5112.114",
	"20.1.4": "104.0.5112.114",
	"20.2.0": "104.0.5112.124",
	"20.3.0": "104.0.5112.124",
	"20.3.1": "104.0.5112.124",
	"20.3.2": "104.0.5112.124",
	"20.3.3": "104.0.5112.124",
	"20.3.4": "104.0.5112.124",
	"20.3.5": "104.0.5112.124",
	"20.3.6": "104.0.5112.124",
	"20.3.7": "104.0.5112.124",
	"20.3.8": "104.0.5112.124",
	"20.3.9": "104.0.5112.124",
	"20.3.10": "104.0.5112.124",
	"20.3.11": "104.0.5112.124",
	"20.3.12": "104.0.5112.124",
	"21.0.0-alpha.1": "105.0.5187.0",
	"21.0.0-alpha.2": "105.0.5187.0",
	"21.0.0-alpha.3": "105.0.5187.0",
	"21.0.0-alpha.4": "105.0.5187.0",
	"21.0.0-alpha.5": "105.0.5187.0",
	"21.0.0-alpha.6": "106.0.5216.0",
	"21.0.0-beta.1": "106.0.5216.0",
	"21.0.0-beta.2": "106.0.5216.0",
	"21.0.0-beta.3": "106.0.5216.0",
	"21.0.0-beta.4": "106.0.5216.0",
	"21.0.0-beta.5": "106.0.5216.0",
	"21.0.0-beta.6": "106.0.5249.40",
	"21.0.0-beta.7": "106.0.5249.40",
	"21.0.0-beta.8": "106.0.5249.40",
	"21.0.0": "106.0.5249.51",
	"21.0.1": "106.0.5249.61",
	"21.1.0": "106.0.5249.91",
	"21.1.1": "106.0.5249.103",
	"21.2.0": "106.0.5249.119",
	"21.2.1": "106.0.5249.165",
	"21.2.2": "106.0.5249.168",
	"21.2.3": "106.0.5249.168",
	"21.3.0": "106.0.5249.181",
	"21.3.1": "106.0.5249.181",
	"21.3.3": "106.0.5249.199",
	"21.3.4": "106.0.5249.199",
	"21.3.5": "106.0.5249.199",
	"21.4.0": "106.0.5249.199",
	"21.4.1": "106.0.5249.199",
	"21.4.2": "106.0.5249.199",
	"21.4.3": "106.0.5249.199",
	"21.4.4": "106.0.5249.199",
	"22.0.0-alpha.1": "107.0.5286.0",
	"22.0.0-alpha.3": "108.0.5329.0",
	"22.0.0-alpha.4": "108.0.5329.0",
	"22.0.0-alpha.5": "108.0.5329.0",
	"22.0.0-alpha.6": "108.0.5329.0",
	"22.0.0-alpha.7": "108.0.5355.0",
	"22.0.0-alpha.8": "108.0.5359.10",
	"22.0.0-beta.1": "108.0.5359.10",
	"22.0.0-beta.2": "108.0.5359.10",
	"22.0.0-beta.3": "108.0.5359.10",
	"22.0.0-beta.4": "108.0.5359.29",
	"22.0.0-beta.5": "108.0.5359.40",
	"22.0.0-beta.6": "108.0.5359.40",
	"22.0.0-beta.7": "108.0.5359.48",
	"22.0.0-beta.8": "108.0.5359.48",
	"22.0.0": "108.0.5359.62",
	"22.0.1": "108.0.5359.125",
	"22.0.2": "108.0.5359.179",
	"22.0.3": "108.0.5359.179",
	"22.1.0": "108.0.5359.179",
	"22.2.0": "108.0.5359.215",
	"22.2.1": "108.0.5359.215",
	"22.3.0": "108.0.5359.215",
	"22.3.1": "108.0.5359.215",
	"22.3.2": "108.0.5359.215",
	"22.3.3": "108.0.5359.215",
	"22.3.4": "108.0.5359.215",
	"22.3.5": "108.0.5359.215",
	"22.3.6": "108.0.5359.215",
	"22.3.7": "108.0.5359.215",
	"22.3.8": "108.0.5359.215",
	"22.3.9": "108.0.5359.215",
	"22.3.10": "108.0.5359.215",
	"22.3.11": "108.0.5359.215",
	"22.3.12": "108.0.5359.215",
	"22.3.13": "108.0.5359.215",
	"22.3.14": "108.0.5359.215",
	"22.3.15": "108.0.5359.215",
	"22.3.16": "108.0.5359.215",
	"22.3.17": "108.0.5359.215",
	"22.3.18": "108.0.5359.215",
	"22.3.20": "108.0.5359.215",
	"22.3.21": "108.0.5359.215",
	"22.3.22": "108.0.5359.215",
	"22.3.23": "108.0.5359.215",
	"22.3.24": "108.0.5359.215",
	"22.3.25": "108.0.5359.215",
	"22.3.26": "108.0.5359.215",
	"22.3.27": "108.0.5359.215",
	"23.0.0-alpha.1": "110.0.5415.0",
	"23.0.0-alpha.2": "110.0.5451.0",
	"23.0.0-alpha.3": "110.0.5451.0",
	"23.0.0-beta.1": "110.0.5478.5",
	"23.0.0-beta.2": "110.0.5478.5",
	"23.0.0-beta.3": "110.0.5478.5",
	"23.0.0-beta.4": "110.0.5481.30",
	"23.0.0-beta.5": "110.0.5481.38",
	"23.0.0-beta.6": "110.0.5481.52",
	"23.0.0-beta.8": "110.0.5481.52",
	"23.0.0": "110.0.5481.77",
	"23.1.0": "110.0.5481.100",
	"23.1.1": "110.0.5481.104",
	"23.1.2": "110.0.5481.177",
	"23.1.3": "110.0.5481.179",
	"23.1.4": "110.0.5481.192",
	"23.2.0": "110.0.5481.192",
	"23.2.1": "110.0.5481.208",
	"23.2.2": "110.0.5481.208",
	"23.2.3": "110.0.5481.208",
	"23.2.4": "110.0.5481.208",
	"23.3.0": "110.0.5481.208",
	"23.3.1": "110.0.5481.208",
	"23.3.2": "110.0.5481.208",
	"23.3.3": "110.0.5481.208",
	"23.3.4": "110.0.5481.208",
	"23.3.5": "110.0.5481.208",
	"23.3.6": "110.0.5481.208",
	"23.3.7": "110.0.5481.208",
	"23.3.8": "110.0.5481.208",
	"23.3.9": "110.0.5481.208",
	"23.3.10": "110.0.5481.208",
	"23.3.11": "110.0.5481.208",
	"23.3.12": "110.0.5481.208",
	"23.3.13": "110.0.5481.208",
	"24.0.0-alpha.1": "111.0.5560.0",
	"24.0.0-alpha.2": "111.0.5560.0",
	"24.0.0-alpha.3": "111.0.5560.0",
	"24.0.0-alpha.4": "111.0.5560.0",
	"24.0.0-alpha.5": "111.0.5560.0",
	"24.0.0-alpha.6": "111.0.5560.0",
	"24.0.0-alpha.7": "111.0.5560.0",
	"24.0.0-beta.1": "111.0.5563.50",
	"24.0.0-beta.2": "111.0.5563.50",
	"24.0.0-beta.3": "112.0.5615.20",
	"24.0.0-beta.4": "112.0.5615.20",
	"24.0.0-beta.5": "112.0.5615.29",
	"24.0.0-beta.6": "112.0.5615.39",
	"24.0.0-beta.7": "112.0.5615.39",
	"24.0.0": "112.0.5615.49",
	"24.1.0": "112.0.5615.50",
	"24.1.1": "112.0.5615.50",
	"24.1.2": "112.0.5615.87",
	"24.1.3": "112.0.5615.165",
	"24.2.0": "112.0.5615.165",
	"24.3.0": "112.0.5615.165",
	"24.3.1": "112.0.5615.183",
	"24.4.0": "112.0.5615.204",
	"24.4.1": "112.0.5615.204",
	"24.5.0": "112.0.5615.204",
	"24.5.1": "112.0.5615.204",
	"24.6.0": "112.0.5615.204",
	"24.6.1": "112.0.5615.204",
	"24.6.2": "112.0.5615.204",
	"24.6.3": "112.0.5615.204",
	"24.6.4": "112.0.5615.204",
	"24.6.5": "112.0.5615.204",
	"24.7.0": "112.0.5615.204",
	"24.7.1": "112.0.5615.204",
	"24.8.0": "112.0.5615.204",
	"24.8.1": "112.0.5615.204",
	"24.8.2": "112.0.5615.204",
	"24.8.3": "112.0.5615.204",
	"24.8.4": "112.0.5615.204",
	"24.8.5": "112.0.5615.204",
	"24.8.6": "112.0.5615.204",
	"24.8.7": "112.0.5615.204",
	"24.8.8": "112.0.5615.204",
	"25.0.0-alpha.1": "114.0.5694.0",
	"25.0.0-alpha.2": "114.0.5694.0",
	"25.0.0-alpha.3": "114.0.5710.0",
	"25.0.0-alpha.4": "114.0.5710.0",
	"25.0.0-alpha.5": "114.0.5719.0",
	"25.0.0-alpha.6": "114.0.5719.0",
	"25.0.0-beta.1": "114.0.5719.0",
	"25.0.0-beta.2": "114.0.5719.0",
	"25.0.0-beta.3": "114.0.5719.0",
	"25.0.0-beta.4": "114.0.5735.16",
	"25.0.0-beta.5": "114.0.5735.16",
	"25.0.0-beta.6": "114.0.5735.16",
	"25.0.0-beta.7": "114.0.5735.16",
	"25.0.0-beta.8": "114.0.5735.35",
	"25.0.0-beta.9": "114.0.5735.45",
	"25.0.0": "114.0.5735.45",
	"25.0.1": "114.0.5735.45",
	"25.1.0": "114.0.5735.106",
	"25.1.1": "114.0.5735.106",
	"25.2.0": "114.0.5735.134",
	"25.3.0": "114.0.5735.199",
	"25.3.1": "114.0.5735.243",
	"25.3.2": "114.0.5735.248",
	"25.4.0": "114.0.5735.248",
	"25.5.0": "114.0.5735.289",
	"25.6.0": "114.0.5735.289",
	"25.7.0": "114.0.5735.289",
	"25.8.0": "114.0.5735.289",
	"25.8.1": "114.0.5735.289",
	"25.8.2": "114.0.5735.289",
	"25.8.3": "114.0.5735.289",
	"25.8.4": "114.0.5735.289",
	"25.9.0": "114.0.5735.289",
	"25.9.1": "114.0.5735.289",
	"25.9.2": "114.0.5735.289",
	"25.9.3": "114.0.5735.289",
	"25.9.4": "114.0.5735.289",
	"25.9.5": "114.0.5735.289",
	"25.9.6": "114.0.5735.289",
	"25.9.7": "114.0.5735.289",
	"25.9.8": "114.0.5735.289",
	"26.0.0-alpha.1": "116.0.5791.0",
	"26.0.0-alpha.2": "116.0.5791.0",
	"26.0.0-alpha.3": "116.0.5791.0",
	"26.0.0-alpha.4": "116.0.5791.0",
	"26.0.0-alpha.5": "116.0.5791.0",
	"26.0.0-alpha.6": "116.0.5815.0",
	"26.0.0-alpha.7": "116.0.5831.0",
	"26.0.0-alpha.8": "116.0.5845.0",
	"26.0.0-beta.1": "116.0.5845.0",
	"26.0.0-beta.2": "116.0.5845.14",
	"26.0.0-beta.3": "116.0.5845.14",
	"26.0.0-beta.4": "116.0.5845.14",
	"26.0.0-beta.5": "116.0.5845.14",
	"26.0.0-beta.6": "116.0.5845.14",
	"26.0.0-beta.7": "116.0.5845.14",
	"26.0.0-beta.8": "116.0.5845.42",
	"26.0.0-beta.9": "116.0.5845.42",
	"26.0.0-beta.10": "116.0.5845.49",
	"26.0.0-beta.11": "116.0.5845.49",
	"26.0.0-beta.12": "116.0.5845.62",
	"26.0.0": "116.0.5845.82",
	"26.1.0": "116.0.5845.97",
	"26.2.0": "116.0.5845.179",
	"26.2.1": "116.0.5845.188",
	"26.2.2": "116.0.5845.190",
	"26.2.3": "116.0.5845.190",
	"26.2.4": "116.0.5845.190",
	"26.3.0": "116.0.5845.228",
	"26.4.0": "116.0.5845.228",
	"26.4.1": "116.0.5845.228",
	"26.4.2": "116.0.5845.228",
	"26.4.3": "116.0.5845.228",
	"26.5.0": "116.0.5845.228",
	"26.6.0": "116.0.5845.228",
	"26.6.1": "116.0.5845.228",
	"26.6.2": "116.0.5845.228",
	"26.6.3": "116.0.5845.228",
	"26.6.4": "116.0.5845.228",
	"26.6.5": "116.0.5845.228",
	"26.6.6": "116.0.5845.228",
	"26.6.7": "116.0.5845.228",
	"26.6.8": "116.0.5845.228",
	"26.6.9": "116.0.5845.228",
	"26.6.10": "116.0.5845.228",
	"27.0.0-alpha.1": "118.0.5949.0",
	"27.0.0-alpha.2": "118.0.5949.0",
	"27.0.0-alpha.3": "118.0.5949.0",
	"27.0.0-alpha.4": "118.0.5949.0",
	"27.0.0-alpha.5": "118.0.5949.0",
	"27.0.0-alpha.6": "118.0.5949.0",
	"27.0.0-beta.1": "118.0.5993.5",
	"27.0.0-beta.2": "118.0.5993.5",
	"27.0.0-beta.3": "118.0.5993.5",
	"27.0.0-beta.4": "118.0.5993.11",
	"27.0.0-beta.5": "118.0.5993.18",
	"27.0.0-beta.6": "118.0.5993.18",
	"27.0.0-beta.7": "118.0.5993.18",
	"27.0.0-beta.8": "118.0.5993.18",
	"27.0.0-beta.9": "118.0.5993.18",
	"27.0.0": "118.0.5993.54",
	"27.0.1": "118.0.5993.89",
	"27.0.2": "118.0.5993.89",
	"27.0.3": "118.0.5993.120",
	"27.0.4": "118.0.5993.129",
	"27.1.0": "118.0.5993.144",
	"27.1.2": "118.0.5993.144",
	"27.1.3": "118.0.5993.159",
	"27.2.0": "118.0.5993.159",
	"27.2.1": "118.0.5993.159",
	"27.2.2": "118.0.5993.159",
	"27.2.3": "118.0.5993.159",
	"27.2.4": "118.0.5993.159",
	"27.3.0": "118.0.5993.159",
	"27.3.1": "118.0.5993.159",
	"27.3.2": "118.0.5993.159",
	"27.3.3": "118.0.5993.159",
	"27.3.4": "118.0.5993.159",
	"27.3.5": "118.0.5993.159",
	"27.3.6": "118.0.5993.159",
	"27.3.7": "118.0.5993.159",
	"27.3.8": "118.0.5993.159",
	"27.3.9": "118.0.5993.159",
	"27.3.10": "118.0.5993.159",
	"27.3.11": "118.0.5993.159",
	"28.0.0-alpha.1": "119.0.6045.0",
	"28.0.0-alpha.2": "119.0.6045.0",
	"28.0.0-alpha.3": "119.0.6045.21",
	"28.0.0-alpha.4": "119.0.6045.21",
	"28.0.0-alpha.5": "119.0.6045.33",
	"28.0.0-alpha.6": "119.0.6045.33",
	"28.0.0-alpha.7": "119.0.6045.33",
	"28.0.0-beta.1": "119.0.6045.33",
	"28.0.0-beta.2": "120.0.6099.0",
	"28.0.0-beta.3": "120.0.6099.5",
	"28.0.0-beta.4": "120.0.6099.5",
	"28.0.0-beta.5": "120.0.6099.18",
	"28.0.0-beta.6": "120.0.6099.18",
	"28.0.0-beta.7": "120.0.6099.18",
	"28.0.0-beta.8": "120.0.6099.18",
	"28.0.0-beta.9": "120.0.6099.18",
	"28.0.0-beta.10": "120.0.6099.18",
	"28.0.0-beta.11": "120.0.6099.35",
	"28.0.0": "120.0.6099.56",
	"28.1.0": "120.0.6099.109",
	"28.1.1": "120.0.6099.109",
	"28.1.2": "120.0.6099.199",
	"28.1.3": "120.0.6099.199",
	"28.1.4": "120.0.6099.216",
	"28.2.0": "120.0.6099.227",
	"28.2.1": "120.0.6099.268",
	"28.2.2": "120.0.6099.276",
	"28.2.3": "120.0.6099.283",
	"28.2.4": "120.0.6099.291",
	"28.2.5": "120.0.6099.291",
	"28.2.6": "120.0.6099.291",
	"28.2.7": "120.0.6099.291",
	"28.2.8": "120.0.6099.291",
	"28.2.9": "120.0.6099.291",
	"28.2.10": "120.0.6099.291",
	"28.3.0": "120.0.6099.291",
	"28.3.1": "120.0.6099.291",
	"28.3.2": "120.0.6099.291",
	"28.3.3": "120.0.6099.291",
	"29.0.0-alpha.1": "121.0.6147.0",
	"29.0.0-alpha.2": "121.0.6147.0",
	"29.0.0-alpha.3": "121.0.6147.0",
	"29.0.0-alpha.4": "121.0.6159.0",
	"29.0.0-alpha.5": "121.0.6159.0",
	"29.0.0-alpha.6": "121.0.6159.0",
	"29.0.0-alpha.7": "121.0.6159.0",
	"29.0.0-alpha.8": "122.0.6194.0",
	"29.0.0-alpha.9": "122.0.6236.2",
	"29.0.0-alpha.10": "122.0.6236.2",
	"29.0.0-alpha.11": "122.0.6236.2",
	"29.0.0-beta.1": "122.0.6236.2",
	"29.0.0-beta.2": "122.0.6236.2",
	"29.0.0-beta.3": "122.0.6261.6",
	"29.0.0-beta.4": "122.0.6261.6",
	"29.0.0-beta.5": "122.0.6261.18",
	"29.0.0-beta.6": "122.0.6261.18",
	"29.0.0-beta.7": "122.0.6261.18",
	"29.0.0-beta.8": "122.0.6261.18",
	"29.0.0-beta.9": "122.0.6261.18",
	"29.0.0-beta.10": "122.0.6261.18",
	"29.0.0-beta.11": "122.0.6261.18",
	"29.0.0-beta.12": "122.0.6261.29",
	"29.0.0": "122.0.6261.39",
	"29.0.1": "122.0.6261.57",
	"29.1.0": "122.0.6261.70",
	"29.1.1": "122.0.6261.111",
	"29.1.2": "122.0.6261.112",
	"29.1.3": "122.0.6261.112",
	"29.1.4": "122.0.6261.129",
	"29.1.5": "122.0.6261.130",
	"29.1.6": "122.0.6261.139",
	"29.2.0": "122.0.6261.156",
	"29.3.0": "122.0.6261.156",
	"29.3.1": "122.0.6261.156",
	"29.3.2": "122.0.6261.156",
	"29.3.3": "122.0.6261.156",
	"29.4.0": "122.0.6261.156",
	"29.4.1": "122.0.6261.156",
	"29.4.2": "122.0.6261.156",
	"29.4.3": "122.0.6261.156",
	"29.4.4": "122.0.6261.156",
	"29.4.5": "122.0.6261.156",
	"29.4.6": "122.0.6261.156",
	"30.0.0-alpha.1": "123.0.6296.0",
	"30.0.0-alpha.2": "123.0.6312.5",
	"30.0.0-alpha.3": "124.0.6323.0",
	"30.0.0-alpha.4": "124.0.6323.0",
	"30.0.0-alpha.5": "124.0.6331.0",
	"30.0.0-alpha.6": "124.0.6331.0",
	"30.0.0-alpha.7": "124.0.6353.0",
	"30.0.0-beta.1": "124.0.6359.0",
	"30.0.0-beta.2": "124.0.6359.0",
	"30.0.0-beta.3": "124.0.6367.9",
	"30.0.0-beta.4": "124.0.6367.9",
	"30.0.0-beta.5": "124.0.6367.9",
	"30.0.0-beta.6": "124.0.6367.18",
	"30.0.0-beta.7": "124.0.6367.29",
	"30.0.0-beta.8": "124.0.6367.29",
	"30.0.0": "124.0.6367.49",
	"30.0.1": "124.0.6367.60",
	"30.0.2": "124.0.6367.91",
	"30.0.3": "124.0.6367.119",
	"30.0.4": "124.0.6367.201",
	"30.0.5": "124.0.6367.207",
	"30.0.6": "124.0.6367.207",
	"30.0.7": "124.0.6367.221",
	"30.0.8": "124.0.6367.230",
	"30.0.9": "124.0.6367.233",
	"30.1.0": "124.0.6367.243",
	"30.1.1": "124.0.6367.243",
	"30.1.2": "124.0.6367.243",
	"30.2.0": "124.0.6367.243",
	"30.3.0": "124.0.6367.243",
	"30.3.1": "124.0.6367.243",
	"30.4.0": "124.0.6367.243",
	"30.5.0": "124.0.6367.243",
	"30.5.1": "124.0.6367.243",
	"31.0.0-alpha.1": "125.0.6412.0",
	"31.0.0-alpha.2": "125.0.6412.0",
	"31.0.0-alpha.3": "125.0.6412.0",
	"31.0.0-alpha.4": "125.0.6412.0",
	"31.0.0-alpha.5": "125.0.6412.0",
	"31.0.0-beta.1": "126.0.6445.0",
	"31.0.0-beta.2": "126.0.6445.0",
	"31.0.0-beta.3": "126.0.6445.0",
	"31.0.0-beta.4": "126.0.6445.0",
	"31.0.0-beta.5": "126.0.6445.0",
	"31.0.0-beta.6": "126.0.6445.0",
	"31.0.0-beta.7": "126.0.6445.0",
	"31.0.0-beta.8": "126.0.6445.0",
	"31.0.0-beta.9": "126.0.6445.0",
	"31.0.0-beta.10": "126.0.6478.36",
	"31.0.0": "126.0.6478.36",
	"31.0.1": "126.0.6478.36",
	"31.0.2": "126.0.6478.61",
	"31.1.0": "126.0.6478.114",
	"31.2.0": "126.0.6478.127",
	"31.2.1": "126.0.6478.127",
	"31.3.0": "126.0.6478.183",
	"31.3.1": "126.0.6478.185",
	"31.4.0": "126.0.6478.234",
	"31.5.0": "126.0.6478.234",
	"31.6.0": "126.0.6478.234",
	"31.7.0": "126.0.6478.234",
	"31.7.1": "126.0.6478.234",
	"31.7.2": "126.0.6478.234",
	"31.7.3": "126.0.6478.234",
	"31.7.4": "126.0.6478.234",
	"31.7.5": "126.0.6478.234",
	"31.7.6": "126.0.6478.234",
	"31.7.7": "126.0.6478.234",
	"32.0.0-alpha.1": "127.0.6521.0",
	"32.0.0-alpha.2": "127.0.6521.0",
	"32.0.0-alpha.3": "127.0.6521.0",
	"32.0.0-alpha.4": "127.0.6521.0",
	"32.0.0-alpha.5": "127.0.6521.0",
	"32.0.0-alpha.6": "128.0.6571.0",
	"32.0.0-alpha.7": "128.0.6571.0",
	"32.0.0-alpha.8": "128.0.6573.0",
	"32.0.0-alpha.9": "128.0.6573.0",
	"32.0.0-alpha.10": "128.0.6573.0",
	"32.0.0-beta.1": "128.0.6573.0",
	"32.0.0-beta.2": "128.0.6611.0",
	"32.0.0-beta.3": "128.0.6613.7",
	"32.0.0-beta.4": "128.0.6613.18",
	"32.0.0-beta.5": "128.0.6613.27",
	"32.0.0-beta.6": "128.0.6613.27",
	"32.0.0-beta.7": "128.0.6613.27",
	"32.0.0": "128.0.6613.36",
	"32.0.1": "128.0.6613.36",
	"32.0.2": "128.0.6613.84",
	"32.1.0": "128.0.6613.120",
	"32.1.1": "128.0.6613.137",
	"32.1.2": "128.0.6613.162",
	"32.2.0": "128.0.6613.178",
	"32.2.1": "128.0.6613.186",
	"32.2.2": "128.0.6613.186",
	"32.2.3": "128.0.6613.186",
	"32.2.4": "128.0.6613.186",
	"32.2.5": "128.0.6613.186",
	"32.2.6": "128.0.6613.186",
	"32.2.7": "128.0.6613.186",
	"32.2.8": "128.0.6613.186",
	"32.3.0": "128.0.6613.186",
	"32.3.1": "128.0.6613.186",
	"32.3.2": "128.0.6613.186",
	"32.3.3": "128.0.6613.186",
	"33.0.0-alpha.1": "129.0.6668.0",
	"33.0.0-alpha.2": "130.0.6672.0",
	"33.0.0-alpha.3": "130.0.6672.0",
	"33.0.0-alpha.4": "130.0.6672.0",
	"33.0.0-alpha.5": "130.0.6672.0",
	"33.0.0-alpha.6": "130.0.6672.0",
	"33.0.0-beta.1": "130.0.6672.0",
	"33.0.0-beta.2": "130.0.6672.0",
	"33.0.0-beta.3": "130.0.6672.0",
	"33.0.0-beta.4": "130.0.6672.0",
	"33.0.0-beta.5": "130.0.6723.19",
	"33.0.0-beta.6": "130.0.6723.19",
	"33.0.0-beta.7": "130.0.6723.19",
	"33.0.0-beta.8": "130.0.6723.31",
	"33.0.0-beta.9": "130.0.6723.31",
	"33.0.0-beta.10": "130.0.6723.31",
	"33.0.0-beta.11": "130.0.6723.44",
	"33.0.0": "130.0.6723.44",
	"33.0.1": "130.0.6723.59",
	"33.0.2": "130.0.6723.59",
	"33.1.0": "130.0.6723.91",
	"33.2.0": "130.0.6723.118",
	"33.2.1": "130.0.6723.137",
	"33.3.0": "130.0.6723.152",
	"33.3.1": "130.0.6723.170",
	"33.3.2": "130.0.6723.191",
	"33.4.0": "130.0.6723.191",
	"33.4.1": "130.0.6723.191",
	"33.4.2": "130.0.6723.191",
	"33.4.3": "130.0.6723.191",
	"33.4.4": "130.0.6723.191",
	"33.4.5": "130.0.6723.191",
	"33.4.6": "130.0.6723.191",
	"33.4.7": "130.0.6723.191",
	"33.4.8": "130.0.6723.191",
	"33.4.9": "130.0.6723.191",
	"33.4.10": "130.0.6723.191",
	"33.4.11": "130.0.6723.191",
	"34.0.0-alpha.1": "131.0.6776.0",
	"34.0.0-alpha.2": "132.0.6779.0",
	"34.0.0-alpha.3": "132.0.6789.1",
	"34.0.0-alpha.4": "132.0.6789.1",
	"34.0.0-alpha.5": "132.0.6789.1",
	"34.0.0-alpha.6": "132.0.6789.1",
	"34.0.0-alpha.7": "132.0.6789.1",
	"34.0.0-alpha.8": "132.0.6820.0",
	"34.0.0-alpha.9": "132.0.6824.0",
	"34.0.0-beta.1": "132.0.6824.0",
	"34.0.0-beta.2": "132.0.6824.0",
	"34.0.0-beta.3": "132.0.6824.0",
	"34.0.0-beta.4": "132.0.6834.6",
	"34.0.0-beta.5": "132.0.6834.6",
	"34.0.0-beta.6": "132.0.6834.15",
	"34.0.0-beta.7": "132.0.6834.15",
	"34.0.0-beta.8": "132.0.6834.15",
	"34.0.0-beta.9": "132.0.6834.32",
	"34.0.0-beta.10": "132.0.6834.32",
	"34.0.0-beta.11": "132.0.6834.32",
	"34.0.0-beta.12": "132.0.6834.46",
	"34.0.0-beta.13": "132.0.6834.46",
	"34.0.0-beta.14": "132.0.6834.57",
	"34.0.0-beta.15": "132.0.6834.57",
	"34.0.0-beta.16": "132.0.6834.57",
	"34.0.0": "132.0.6834.83",
	"34.0.1": "132.0.6834.83",
	"34.0.2": "132.0.6834.159",
	"34.1.0": "132.0.6834.194",
	"34.1.1": "132.0.6834.194",
	"34.2.0": "132.0.6834.196",
	"34.3.0": "132.0.6834.210",
	"34.3.1": "132.0.6834.210",
	"34.3.2": "132.0.6834.210",
	"34.3.3": "132.0.6834.210",
	"34.3.4": "132.0.6834.210",
	"34.4.0": "132.0.6834.210",
	"34.4.1": "132.0.6834.210",
	"34.5.0": "132.0.6834.210",
	"34.5.1": "132.0.6834.210",
	"34.5.2": "132.0.6834.210",
	"34.5.3": "132.0.6834.210",
	"34.5.4": "132.0.6834.210",
	"34.5.5": "132.0.6834.210",
	"34.5.6": "132.0.6834.210",
	"34.5.7": "132.0.6834.210",
	"34.5.8": "132.0.6834.210",
	"35.0.0-alpha.1": "133.0.6920.0",
	"35.0.0-alpha.2": "133.0.6920.0",
	"35.0.0-alpha.3": "133.0.6920.0",
	"35.0.0-alpha.4": "133.0.6920.0",
	"35.0.0-alpha.5": "133.0.6920.0",
	"35.0.0-beta.1": "133.0.6920.0",
	"35.0.0-beta.2": "134.0.6968.0",
	"35.0.0-beta.3": "134.0.6968.0",
	"35.0.0-beta.4": "134.0.6968.0",
	"35.0.0-beta.5": "134.0.6989.0",
	"35.0.0-beta.6": "134.0.6990.0",
	"35.0.0-beta.7": "134.0.6990.0",
	"35.0.0-beta.8": "134.0.6998.10",
	"35.0.0-beta.9": "134.0.6998.10",
	"35.0.0-beta.10": "134.0.6998.23",
	"35.0.0-beta.11": "134.0.6998.23",
	"35.0.0-beta.12": "134.0.6998.23",
	"35.0.0-beta.13": "134.0.6998.44",
	"35.0.0": "134.0.6998.44",
	"35.0.1": "134.0.6998.44",
	"35.0.2": "134.0.6998.88",
	"35.0.3": "134.0.6998.88",
	"35.1.0": "134.0.6998.165",
	"35.1.1": "134.0.6998.165",
	"35.1.2": "134.0.6998.178",
	"35.1.3": "134.0.6998.179",
	"35.1.4": "134.0.6998.179",
	"35.1.5": "134.0.6998.179",
	"35.2.0": "134.0.6998.205",
	"35.2.1": "134.0.6998.205",
	"35.2.2": "134.0.6998.205",
	"35.3.0": "134.0.6998.205",
	"35.4.0": "134.0.6998.205",
	"35.5.0": "134.0.6998.205",
	"35.5.1": "134.0.6998.205",
	"36.0.0-alpha.1": "135.0.7049.5",
	"36.0.0-alpha.2": "136.0.7062.0",
	"36.0.0-alpha.3": "136.0.7062.0",
	"36.0.0-alpha.4": "136.0.7062.0",
	"36.0.0-alpha.5": "136.0.7067.0",
	"36.0.0-alpha.6": "136.0.7067.0",
	"36.0.0-beta.1": "136.0.7067.0",
	"36.0.0-beta.2": "136.0.7067.0",
	"36.0.0-beta.3": "136.0.7067.0",
	"36.0.0-beta.4": "136.0.7067.0",
	"36.0.0-beta.5": "136.0.7103.17",
	"36.0.0-beta.6": "136.0.7103.25",
	"36.0.0-beta.7": "136.0.7103.25",
	"36.0.0-beta.8": "136.0.7103.33",
	"36.0.0-beta.9": "136.0.7103.33",
	"36.0.0": "136.0.7103.48",
	"36.0.1": "136.0.7103.48",
	"36.1.0": "136.0.7103.49",
	"36.2.0": "136.0.7103.49",
	"36.2.1": "136.0.7103.93",
	"36.3.0": "136.0.7103.113",
	"36.3.1": "136.0.7103.113",
	"36.3.2": "136.0.7103.115",
	"36.4.0": "136.0.7103.149",
	"37.0.0-alpha.1": "137.0.7151.0",
	"37.0.0-alpha.2": "137.0.7151.0",
	"37.0.0-alpha.3": "138.0.7156.0",
	"37.0.0-alpha.4": "138.0.7165.0",
	"37.0.0-alpha.5": "138.0.7177.0",
	"37.0.0-alpha.6": "138.0.7178.0",
	"37.0.0-alpha.7": "138.0.7178.0",
	"37.0.0-beta.1": "138.0.7178.0",
	"37.0.0-beta.2": "138.0.7178.0",
	"37.0.0-beta.3": "138.0.7190.0",
	"37.0.0-beta.4": "138.0.7204.15"
};